/**
 * Card object
 *
 * @author Kiana Agha Kasiri
 */
public class Card {

    /**
     * color of the card
     */
    private String cardColor;
    /**
     * value of the card
     */
    private String cardValue;
    /**
     * type of the card
     */
    private CardType cardType;
    /**
     * score of the card
     */
    private int cardScore;

    /**
     * Constructor
     * @param cardType type
     */
    public Card(CardType cardType) { initialize(cardType); }

    /**
     * Constructor
     * @param cardColor color
     * @param cardValue value
     */
    public Card(String cardColor, String cardValue) {
        for (CardType type : CardType.values())
            if (type.name().equals(cardColor + "_" + cardValue)) {
                initialize(type);
                break;
            }
    }

    /**
     * initializing the card type, color, value, ...
     * @param cardType type
     */
    private void initialize(CardType cardType) {

        this.cardType = cardType;
        String cardType_string = cardType.toString();

        if (cardType == CardType.WILD || cardType == CardType.WILD_DRAW4) { // Wild cards
            cardScore = 50;
            cardColor = "WILD";
            if (cardType == CardType.WILD)
                cardValue = "WILD";
            else
                cardValue = "DRAW4";
        } else if (cardType_string.contains("_SKIP") || cardType_string.contains("_REVERSE") || cardType_string.contains("_DRAW2")) { // Action cards
            cardScore = 20;
            cardColor = cardType_string.split("_")[0];
            cardValue = cardType_string.split("_")[1];
        } else {    // Ordinary cards
            cardScore = Integer.parseInt(cardType_string.split("_")[1]);
            cardColor = cardType_string.split("_")[0];
            cardValue = cardType_string.split("_")[1];
        }

        // Adjust the card color according to the available Console Color
        adjustConsoleColor();
    }

    /**
     * Get card type
     * @return type
     */
    public CardType getCardType() {
        return cardType;
    }

    /**
     * Get card score
     * @return score
     */
    public int getCardScore() {
        return cardScore;
    }

    /**
     * Get card color
     * @return color
     */
    public String getCardColor() {
        return cardColor;
    }

    /**
     * sets the card's color
     * @param cardColor
     */
    public void setCardColor(String cardColor) {
        cardColor = cardColor;
    }

    /**
     * Get card value
     * @return value
     */
    public String getCardValue() { return cardValue; }

    /**
     * set back color
     */
    private void adjustConsoleColor() {

        if (cardColor.equals("RED")) {
            cardColor = ConsoleColors.RED_BACKGROUND_BRIGHT;
        } else if (this.cardColor.equals("BLUE")) {
            cardColor = ConsoleColors.BLUE_BACKGROUND_BRIGHT;
        } else if (this.cardColor.equals("GREEN")) {
            cardColor = ConsoleColors.GREEN_BACKGROUND_BRIGHT;
        } else if (this.cardColor.equals("YELLOW")) {
            cardColor = ConsoleColors.YELLOW_BACKGROUND_BRIGHT;
        }
    }
}