import java.util.ArrayList;

public class Player {
    private ArrayList<Card> cards;
    private String name;
    private int score;
    private Card lastCard;
    private boolean isAI;

    public Player(String name, boolean isAI) {
        this.name = name;
        this.score = 0;
        this.lastCard = null;
        cards = new ArrayList<>();
        this.isAI = isAI;
    }

    /**
     * gets the last card
     * @return
     */
    public Card getLastCard() {
        return lastCard;
    }

    /**
     * sets the last card
     * @param lastCard
     */
    public void setLastCard(Card lastCard) {
        this.lastCard = lastCard;
    }

    /**
     * gets the player's name
     * @return name
     */
    public String getName() {
        return name;
    }

    /**
     * gets the player's score
     * @return score
     */
    public int getScore() {
        return score;
    }

    /**
     * sets score
     * @param score
     */
    public void setScore(int score) {
        this.score = score;
    }

    /**
     * sets name
     * @param name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * gets the cards
     * @return cards
     */
    public ArrayList<Card> getCards() {
        return cards;
    }

    /**
     * sets the cards
     * @param cards
     */
    public void setCards(ArrayList<Card> cards) {
        this.cards = cards;
    }

    /**
     * adds a card to the list of player's cards
     * @param card
     */
    public void addCard(Card card) {
        cards.add(card);
    }

    /**
     * removes a card from the list of player's cards
     * @param card
     */
    public void removeCard(Card card) {
        cards.remove(card);
    }

    /**
     * changes the last card
     * removes the card from the list of player's cards
     * @param card
     */
    public void lastCardOut(Card card) {
        lastCard = card;
        cards.remove(card);
    }

    public Card play(Card table, String color) {

        for (Card card : cards) {
            if (color.equals("")) {
                if (card.getCardColor().equals(table.getCardColor()))
                    return decide(card);
                if (card.getCardValue().equals(table.getCardValue()))
                    return decide(card);
            } else {
                if (card.getCardColor().equals(color))
                    return decide(card);
            }
        }

        for (Card card : cards)
            if (card.getCardType() == CardType.WILD)
                return decide(card);

        for (Card card : cards)
            if (card.getCardType() == CardType.WILD_DRAW4)
                return decide(card);

        return null;
    }

    /**
     * removing the card
     * @param cardToRemove
     * @return
     */
    public Card decide(Card cardToRemove) {
        //changing the last card
        lastCardOut(cardToRemove);
        // Remove from set
        removeCard(cardToRemove);
        // Now return the card
        return cardToRemove;
    }

    /**
     * if the player is human or computer
     * @return
     */
    public boolean getIsAI() {
        return isAI;
    }

    /**
     * @param userCard
     * @return
     */
    public boolean contains(String userCard) {
        for (Card card : cards)
            if (card.getCardType().name().equals(userCard))
                return true;
        return false;
    }

    /**
     * checks if the cards are the same
     * @param userCard
     * @return
     */
    public Card getEquavalentCard(String userCard) {
        for (Card card: cards)
            if (card.getCardType().name().equals(userCard))
                return card;
        return null;
    }

    /**
     * checking if player has a card to draw
     * @param table
     * @param userCard
     * @return true or false
     */
    public boolean canDraw(Card table, Card userCard, String color) {
        if (userCard.getCardValue().equals(table.getCardValue()) || userCard.getCardColor().equals(table.getCardColor()) || userCard.getCardType() == CardType.WILD)
            return true;
        else {
            boolean isOk = false;
            for (Card card: cards) {
                if (table.getCardValue().equals(card.getCardValue()) || table.getCardColor().equals(card.getCardColor())) {
                    isOk = true;
                    break;
                }
            }

            if (!isOk && userCard.getCardType() == CardType.WILD_DRAW4)
                return true;
        }

        if (userCard.getCardColor().equals(color) || userCard.getCardType() == CardType.WILD)
            return true;
        else {
            boolean isOk = false;
            for (Card card: cards) {
                if (color.equals(card.getCardColor())) {
                    isOk = true;
                    break;
                }
            }

            if (!isOk && userCard.getCardType() == CardType.WILD_DRAW4)
                return true;
        }


        return false;
    }
}